==> PyOfficeRobot-0.1.16.tar.gz: PyOfficeRobot-0.1.16/README.md <==
<p align="center" id='大礼包-banner'>
    <a target="_blank" href='http://python4office.cn/fuli/fuli-source-0726/'>
    <img src="https://banner-1300615378.cos.ap-guangzhou.myqcloud.com/%E6%A8%AA%E6%9D%A1/Python%E5%A4%A7%E7%A4%BC%E5%8C%85.jpg" width="100%"/>
    </a>   
</p>
<p align="center">
	👉 <a target="_blank" href="https://www.python-office.com/office/robot.html">项目官网</a> 👈
</p>
<p align="center">
	👉 <a target="_blank" href="https://python-office-1300615378.cos.ap-chongqing.myqcloud.com/python-office.jpg">本开源项目的交流群</a> 👈
</p>


<p align="center" name="'github">
    <a target="_blank" href='https://github.com/CoderWanFeng/PyOfficeRobot'>
    <img src="https://img.shields.io/github/stars/CoderWanFeng/PyOfficeRobot.svg?style=social" alt="github star"/>
    </a>
    	<a target="_blank" href='https://gitee.com/CoderWanFeng//PyOfficeRobot/'>
		<img src='https://gitee.com/CoderWanFeng//PyOfficeRobot/badge/star.svg?theme=dark' alt='gitee star'/>
	</a>
  	<a href="https://mp.weixin.qq.com/s/yaSmFKO3RrBpyanW3nvRAQ">
	<img src="https://img.shields.io/badge/QQ-163434413-orange"/>
  </a>
    	<a href="https://mp.weixin.qq.com/s/NN2pX2bQPpczOeGF4ARNtw">
	<img src="https://img.shields.io/badge/%E5%BE%AE%E4%BF%A1-%E4%BA%A4%E6%B5%81%E7%BE%A4-brightgreen"/>
  </a>

</p>

# 又一个微信聊天机器人横空出世了，人人可用！

之前给大家分享过一个微信机器人：[一个15分钟的视频，教你用Python创建自己的微信聊天机器人！](http://t.cn/A66p30bI)

但是之前这个机器人，需要基于网页版才能用(有网页版微信的同学，还可以去继续用)；然而很多朋友的微信，是不能登录网页版微信的。

> 有没有一种微信机器人，任何人的微信都可以用，不需要网页微信功能呢？


在经过技术检索和开发以后，支持所有微信使用的：**PyOfficeRobot**来啦~

## 1、安装PyOfficeRobot

1行命令，安装PyOfficeRobot这个库。[安装视频](https://www.bilibili.com/video/BV1Xa411u7yU/)

```
pip install -i https://mirrors.aliyun.com/pypi/simple/ PyOfficeRobot -U
```

## 2、功能演示

- ⭐本机器人完全免费，全部功能的演示视频 +
  项目源码：[Github](https://gitee.com/CoderWanFeng/PyOfficeRobot/demo)、[gitee](https://gitee.com/CoderWanFeng/PyOfficeRobot)

| 序号 | 方法名                  | 功能           | 视频                                                 | 文档       | 代码                                                                                                                                                       |
|----|----------------------|--------------|----------------------------------------------------|----------|----------------------------------------------------------------------------------------------------------------------------------------------------------|
| 1  |                      | 🔥项目发布       | [播放](https://www.bilibili.com/video/BV1Xa411u7yU)  | 待编辑      | [打开](https://mp.weixin.qq.com/s/6slx8hyv_WuK7v5Nzt3XKQ)                                                                                                  |
| 2  | send_message         | 自动发消息        | [播放](https://www.bilibili.com/video/BV1Jt4y1j7F1)  | 待编辑      | [打开](https://gitee.com/CoderWanFeng/python-office/blob/master/demo/PyOfficeRobot/001-%E5%8F%91%E4%B8%80%E6%9D%A1%E4%BF%A1%E6%81%AF.py)                   |
| 3  | send_file            | 自动发文件        | [播放](https://www.bilibili.com/video/BV1te4y1y7Ro)  | 待编辑      | [打开](https://gitee.com/CoderWanFeng/python-office/blob/master/demo/PyOfficeRobot/002-%E5%8F%91%E6%96%87%E4%BB%B6.py)                                     |
| 4  | chat_by_keywords     | 根据关键词，自动回复   | [播放](https://www.bilibili.com/video/BV1fV4y1M7ju)  | 待编辑      | [打开](https://gitee.com/CoderWanFeng/python-office/blob/master/demo/PyOfficeRobot/003-%E6%A0%B9%E6%8D%AE%E5%85%B3%E9%94%AE%E8%AF%8D%E5%9B%9E%E5%A4%8D.py) |
| 5  | send_message_by_time | ⌚定时自动发消息     | [播放](https://www.bilibili.com/video/BV1m8411b7LZ/) | 待编辑      | [打开](https://gitee.com/CoderWanFeng/python-office/blob/master/demo/PyOfficeRobot/004-%E5%AE%9A%E6%97%B6%E5%8F%91%E9%80%81.py)                            |
| 6  |                      | 自己加功能        | [播放](https://www.bilibili.com/video/BV14R4y127h6)  | 待编辑      | [打开](https://gitee.com/CoderWanFeng/python-office/blob/master/demo/PyOfficeRobot/005-%E8%87%AA%E5%AE%9A%E4%B9%89%E5%8A%9F%E8%83%BD.py)                   |
| 7  |                      | ⭐独立使用        | [播放](https://www.bilibili.com/video/BV1SY411y7Uh)  | 待编辑      | [打开](https://gitee.com/CoderWanFeng/python-office/blob/master/demo/PyOfficeRobot/006-%E7%8B%AC%E7%AB%8B%E7%89%88%E6%9C%AC.py)                            |
| 8  | get_group_list       | 收集群信息        | [播放](https://www.bilibili.com/video/BV1eD4y1g7yZ)  | 有BUG，待修复 | [打开](https://gitee.com/CoderWanFeng/python-office/blob/master/demo/PyOfficeRobot/007-%E6%94%B6%E9%9B%86%E7%BE%A4%E6%B6%88%E6%81%AF.py)                   |
| 9  |                      | 发消息如何换行？     | [播放](https://www.bilibili.com/video/BV1Xg4y1s79z/) | 待编辑      | [打开](https://gitee.com/CoderWanFeng/python-office/blob/master/demo/PyOfficeRobot/008-%E5%8F%91%E6%B6%88%E6%81%AF%E6%8D%A2%E8%A1%8C.py)                   |
| 10 | chat_by_gpt          | 微信 + ChatGPT | [播放](https://www.bilibili.com/video/BV1394y1e787)  | 待编辑      | [打开](https://gitee.com/CoderWanFeng/python-office/blob/master/demo/PyOfficeRobot/011-chat_chatgpt.py)                                                    |
| 11 | add                  | 批量加好友        | [播放](https://www.bilibili.com/video/BV1DV4y1o7t2)  | 有BUG，待修复 | [打开](https://gitee.com/CoderWanFeng/python-office/blob/master/demo/PyOfficeRobot/009-%E6%89%B9%E9%87%8F%E5%8A%A0%E5%A5%BD%E5%8F%8B.py)                   |
| 12 | send                 | 批量群发         | [播放](https://www.bilibili.com/video/BV1Nm4y1C7N7)  | 待编辑      | [打开](https://gitee.com/CoderWanFeng/python-office/blob/master/demo/PyOfficeRobot/010-%E5%AE%9A%E6%97%B6%E7%BE%A4%E5%8F%91.py)                            |
| 13 | chat_robot           | 智能聊天         | [播放](https://www.bilibili.com/video/BV1394y1e787)  | 待编辑      | [打开](https://gitee.com/CoderWanFeng/python-office/blob/master/demo/PyOfficeRobot/012%E3%80%81%E6%99%BA%E8%83%BD%E8%81%8A%E5%A4%A9.py)                    |

> 持续更新中，交流群：[点我加入](http://www.python4office.cn/wechat-group/)

#### 微信机器人-其它实现方式

| 功能说明            | 视频                                                   | 代码                                                        |
|-----------------|------------------------------------------------------|-----------------------------------------------------------|
| 机器人.exe         | [点我直达](https://www.bilibili.com/video/BV1Q64y1Z7TB/) |                                                           |
| ChatGPT版本       | [点我直达](https://www.bilibili.com/video/BV1Dx4y157qy)  | [点我直达](https://mp.weixin.qq.com/s/HJfLZILUOWn4TK8qk3DL9w) |
| ⌚wxpy-24小时，后台运行 | [点我直达](https://www.bilibili.com/video/BV11L411L7oi/) | [点我直达](https://mp.weixin.qq.com/s/ubJ1OhOFVKfFVT8sBNZ0pg) |
| 企业微信机器人         |                                                      | [点我直达](https://mp.weixin.qq.com/s/mt-ONvz0DdhbMB96eTZDKA) |

## 3、功能Demo

我最近开源了这个库的全部源代码，功能正在开发中，欢迎大家参与开发~

- [演示代码](https://github.com/CoderWanFeng/PyOfficeRobot/tree/main/demo)

## 4、开发者

| 昵称 | 贡献                    | 时间             |
|----|-----------------------|----------------|
| 雷杰 | 解决了微信更新后，不能发送消息和文件的问题 | 2023/7/6 00：30 |

---

<p align="center" id='开源交流群-banner'>
<a target="_blank" href='https://python-office-1300615378.cos.ap-chongqing.myqcloud.com/python-office.jpg'>
<img src="https://python-office-1300615378.cos.ap-chongqing.myqcloud.com/python-office-qr.jpg" width="100%"/>
</a> 
</p>

## ⭐Star

[![Stargazers over time](https://starchart.cc/CoderWanFeng/PyOfficeRobot.svg)](https://starchart.cc/CoderWanFeng/PyOfficeRobot)

## 📕拓展资料

<p align="center" id='30讲自动化办公-banner'>
    <a target="_blank" href='https://www.python-office.com/video/video.html'>
    <img src="https://website-python-1300615378.cos.ap-nanjing.myqcloud.com/%E5%BC%95%E5%AF%BC%E8%B6%85%E9%93%BE%E6%8E%A5%2Fauto-work.jpg" width="100%"/>
    </a>   
</p>

<p align="center" id='100本电子书-banner'>
    <a target="_blank" href='https://mp.weixin.qq.com/s/H3us6_7wg2QspGZfGtfDZw'>
    <img src="https://website-python-1300615378.cos.ap-nanjing.myqcloud.com/%E5%BC%95%E5%AF%BC%E8%B6%85%E9%93%BE%E6%8E%A5%2Febook.jpg" width="100%"/>
    </a>   
</p>

<p align="center" id='实战项目-banner'>
    <a target="_blank" href='http://www.python4office.cn/python-project-list/'>
    <img src="https://website-python-1300615378.cos.ap-nanjing.myqcloud.com/%E5%BC%95%E5%AF%BC%E8%B6%85%E9%93%BE%E6%8E%A5%2Fproject.jpg" width="100%"/>
    </a>   
</p>

<p align="center" id='11个软件-banner'>
    <a target="_blank" href='https://mp.weixin.qq.com/s/uE1M8ESBQ3wJ_q-Cl1aNvg'>
    <img src="https://website-python-1300615378.cos.ap-nanjing.myqcloud.com/%E5%BC%95%E5%AF%BC%E8%B6%85%E9%93%BE%E6%8E%A5%2Fsoft-11.jpg" width="100%"/>
    </a>   
</p>


<p align="center" id='25个学习资源-banner'>
    <a target="_blank" href='https://mp.weixin.qq.com/s/_01V8I7rVkgvIIo7ygwwQA'>
    <img src="https://website-python-1300615378.cos.ap-nanjing.myqcloud.com/%E5%BC%95%E5%AF%BC%E8%B6%85%E9%93%BE%E6%8E%A5%2Fpy-25-source.jpg" width="100%"/>
    </a>   
</p>

<p align="center" id='支付宝-banner'>
    <a target="_blank" href='https://mp.weixin.qq.com/s/TSnAjBs2dILSI_pM1pPznQ'>
    <img src="https://website-python-1300615378.cos.ap-nanjing.myqcloud.com/ads%2F%E8%81%94%E7%9B%9F%E5%B9%BF%E5%91%8A%2Falipay.jpg" width="100%"/>
    </a>   
</p>


<p align="center" id='外卖-banner'>
    <a target="_blank" href='https://mp.weixin.qq.com/s/fdQ0TbTocPvw-DAMsFUlVg'>
    <img src="https://website-python-1300615378.cos.ap-nanjing.myqcloud.com/ads%2F%E8%81%94%E7%9B%9F%E5%B9%BF%E5%91%8A%2F%E5%A4%96%E5%8D%96-1040-100.jpg" width="100%"/>
    </a>   
</p>

==> PyOfficeRobot-0.1.18.tar.gz: PyOfficeRobot-0.1.18/README.md <==
<p align="center" id='大礼包-banner'>
    <a target="_blank" href='http://python4office.cn/fuli/fuli-source-0726/'>
    <img src="https://banner-1300615378.cos.ap-guangzhou.myqcloud.com/%E6%A8%AA%E6%9D%A1/Python%E5%A4%A7%E7%A4%BC%E5%8C%85.jpg" width="100%"/>
    </a>   
</p>
<p align="center">
	👉 <a target="_blank" href="https://www.python-office.com/office/robot.html">项目官网</a> 👈
</p>
<p align="center">
	👉 <a target="_blank" href="https://python-office-1300615378.cos.ap-chongqing.myqcloud.com/python-office.jpg">本开源项目的交流群</a> 👈
</p>


<p align="center" name="'github">
    <a target="_blank" href='https://github.com/CoderWanFeng/PyOfficeRobot'>
    <img src="https://img.shields.io/github/stars/CoderWanFeng/PyOfficeRobot.svg?style=social" alt="github star"/>
    </a>
    	<a target="_blank" href='https://gitee.com/CoderWanFeng//PyOfficeRobot/'>
		<img src='https://gitee.com/CoderWanFeng//PyOfficeRobot/badge/star.svg?theme=dark' alt='gitee star'/>
	</a>
  	<a href="https://mp.weixin.qq.com/s/yaSmFKO3RrBpyanW3nvRAQ">
	<img src="https://img.shields.io/badge/QQ-163434413-orange"/>
  </a>
    	<a href="https://mp.weixin.qq.com/s/NN2pX2bQPpczOeGF4ARNtw">
	<img src="https://img.shields.io/badge/%E5%BE%AE%E4%BF%A1-%E4%BA%A4%E6%B5%81%E7%BE%A4-brightgreen"/>
  </a>

</p>

# 又一个微信聊天机器人横空出世了，人人可用！

之前给大家分享过一个微信机器人：[一个15分钟的视频，教你用Python创建自己的微信聊天机器人！](http://t.cn/A66p30bI)

但是之前这个机器人，需要基于网页版才能用(有网页版微信的同学，还可以去继续用)；然而很多朋友的微信，是不能登录网页版微信的。

> 有没有一种微信机器人，任何人的微信都可以用，不需要网页微信功能呢？


在经过技术检索和开发以后，支持所有微信使用的：**PyOfficeRobot**来啦~

## 1、安装PyOfficeRobot

1行命令，安装PyOfficeRobot这个库。[安装视频](https://www.bilibili.com/video/BV1Xa411u7yU/)

```
pip install -i https://mirrors.aliyun.com/pypi/simple/ PyOfficeRobot -U
```

## 2、功能演示

- ⭐本机器人完全免费，全部功能的演示视频 +
  项目源码：[Github](https://gitee.com/CoderWanFeng/PyOfficeRobot/demo)、[gitee](https://gitee.com/CoderWanFeng/PyOfficeRobot)

| 序号 | 方法名                  | 功能           | 视频                                                 | 文档       | 代码                                                                                                                                                       |
|----|----------------------|--------------|----------------------------------------------------|----------|----------------------------------------------------------------------------------------------------------------------------------------------------------|
| 1  |                      | 🔥项目发布       | [播放](https://www.bilibili.com/video/BV1Xa411u7yU)  | 待编辑      | [打开](https://mp.weixin.qq.com/s/6slx8hyv_WuK7v5Nzt3XKQ)                                                                                                  |
| 2  | send_message         | 自动发消息        | [播放](https://www.bilibili.com/video/BV1Jt4y1j7F1)  | 待编辑      | [打开](https://gitee.com/CoderWanFeng/python-office/blob/master/demo/PyOfficeRobot/001-%E5%8F%91%E4%B8%80%E6%9D%A1%E4%BF%A1%E6%81%AF.py)                   |
| 3  | send_file            | 自动发文件        | [播放](https://www.bilibili.com/video/BV1te4y1y7Ro)  | 待编辑      | [打开](https://gitee.com/CoderWanFeng/python-office/blob/master/demo/PyOfficeRobot/002-%E5%8F%91%E6%96%87%E4%BB%B6.py)                                     |
| 4  | chat_by_keywords     | 根据关键词，自动回复   | [播放](https://www.bilibili.com/video/BV1fV4y1M7ju)  | 待编辑      | [打开](https://gitee.com/CoderWanFeng/python-office/blob/master/demo/PyOfficeRobot/003-%E6%A0%B9%E6%8D%AE%E5%85%B3%E9%94%AE%E8%AF%8D%E5%9B%9E%E5%A4%8D.py) |
| 5  | send_message_by_time | ⌚定时自动发消息     | [播放](https://www.bilibili.com/video/BV1m8411b7LZ/) | 待编辑      | [打开](https://gitee.com/CoderWanFeng/python-office/blob/master/demo/PyOfficeRobot/004-%E5%AE%9A%E6%97%B6%E5%8F%91%E9%80%81.py)                            |
| 6  |                      | 自己加功能        | [播放](https://www.bilibili.com/video/BV14R4y127h6)  | 待编辑      | [打开](https://gitee.com/CoderWanFeng/python-office/blob/master/demo/PyOfficeRobot/005-%E8%87%AA%E5%AE%9A%E4%B9%89%E5%8A%9F%E8%83%BD.py)                   |
| 7  |                      | ⭐独立使用        | [播放](https://www.bilibili.com/video/BV1SY411y7Uh)  | 待编辑      | [打开](https://gitee.com/CoderWanFeng/python-office/blob/master/demo/PyOfficeRobot/006-%E7%8B%AC%E7%AB%8B%E7%89%88%E6%9C%AC.py)                            |
| 8  | get_group_list       | 收集群信息        | [播放](https://www.bilibili.com/video/BV1eD4y1g7yZ)  | 有BUG，待修复 | [打开](https://gitee.com/CoderWanFeng/python-office/blob/master/demo/PyOfficeRobot/007-%E6%94%B6%E9%9B%86%E7%BE%A4%E6%B6%88%E6%81%AF.py)                   |
| 9  |                      | 发消息如何换行？     | [播放](https://www.bilibili.com/video/BV1Xg4y1s79z/) | 待编辑      | [打开](https://gitee.com/CoderWanFeng/python-office/blob/master/demo/PyOfficeRobot/008-%E5%8F%91%E6%B6%88%E6%81%AF%E6%8D%A2%E8%A1%8C.py)                   |
| 10 | chat_by_gpt          | 微信 + ChatGPT | [播放](https://www.bilibili.com/video/BV1394y1e787)  | 待编辑      | [打开](https://gitee.com/CoderWanFeng/python-office/blob/master/demo/PyOfficeRobot/011-chat_chatgpt.py)                                                    |
| 11 | add                  | 批量加好友        | [播放](https://www.bilibili.com/video/BV1DV4y1o7t2)  | 有BUG，待修复 | [打开](https://gitee.com/CoderWanFeng/python-office/blob/master/demo/PyOfficeRobot/009-%E6%89%B9%E9%87%8F%E5%8A%A0%E5%A5%BD%E5%8F%8B.py)                   |
| 12 | send                 | 批量群发         | [播放](https://www.bilibili.com/video/BV1Nm4y1C7N7)  | 待编辑      | [打开](https://gitee.com/CoderWanFeng/python-office/blob/master/demo/PyOfficeRobot/010-%E5%AE%9A%E6%97%B6%E7%BE%A4%E5%8F%91.py)                            |
| 13 | chat_robot           | 智能聊天         | [播放](https://www.bilibili.com/video/BV1394y1e787)  | 待编辑      | [打开](https://gitee.com/CoderWanFeng/python-office/blob/master/demo/PyOfficeRobot/012%E3%80%81%E6%99%BA%E8%83%BD%E8%81%8A%E5%A4%A9.py)                    |

> 持续更新中，交流群：[点我加入](http://www.python4office.cn/wechat-group/)

#### 微信机器人-其它实现方式

| 功能说明            | 视频                                                   | 代码                                                        |
|-----------------|------------------------------------------------------|-----------------------------------------------------------|
| 机器人.exe         | [点我直达](https://www.bilibili.com/video/BV1Q64y1Z7TB/) |                                                           |
| ChatGPT版本       | [点我直达](https://www.bilibili.com/video/BV1Dx4y157qy)  | [点我直达](https://mp.weixin.qq.com/s/HJfLZILUOWn4TK8qk3DL9w) |
| ⌚wxpy-24小时，后台运行 | [点我直达](https://www.bilibili.com/video/BV11L411L7oi/) | [点我直达](https://mp.weixin.qq.com/s/ubJ1OhOFVKfFVT8sBNZ0pg) |
| 企业微信机器人         |                                                      | [点我直达](https://mp.weixin.qq.com/s/mt-ONvz0DdhbMB96eTZDKA) |

## 3、功能Demo

我最近开源了这个库的全部源代码，功能正在开发中，欢迎大家参与开发~

- [演示代码](https://github.com/CoderWanFeng/PyOfficeRobot/tree/main/demo)

## 4、开发者

| 昵称 | 贡献                    | 时间             |
|----|-----------------------|----------------|
| 雷杰 | 解决了微信更新后，不能发送消息和文件的问题 | 2023/7/6 00：30 |

---

<p align="center" id='开源交流群-banner'>
<a target="_blank" href='https://python-office-1300615378.cos.ap-chongqing.myqcloud.com/python-office.jpg'>
<img src="https://python-office-1300615378.cos.ap-chongqing.myqcloud.com/python-office-qr.jpg" width="100%"/>
</a> 
</p>

## ⭐Star

[![Stargazers over time](https://starchart.cc/CoderWanFeng/PyOfficeRobot.svg)](https://starchart.cc/CoderWanFeng/PyOfficeRobot)

## 📕拓展资料

<p align="center" id='30讲自动化办公-banner'>
    <a target="_blank" href='https://www.python-office.com/video/video.html'>
    <img src="https://website-python-1300615378.cos.ap-nanjing.myqcloud.com/%E5%BC%95%E5%AF%BC%E8%B6%85%E9%93%BE%E6%8E%A5%2Fauto-work.jpg" width="100%"/>
    </a>   
</p>

<p align="center" id='100本电子书-banner'>
    <a target="_blank" href='https://mp.weixin.qq.com/s/6bM_3tROqdY_2WbBShzqyw'>
    <img src="https://website-python-1300615378.cos.ap-nanjing.myqcloud.com/%E5%BC%95%E5%AF%BC%E8%B6%85%E9%93%BE%E6%8E%A5%2Febook.jpg" width="100%"/>
    </a>   
</p>

<p align="center" id='实战项目-banner'>
    <a target="_blank" href='http://www.python4office.cn/python-project-list/'>
    <img src="https://website-python-1300615378.cos.ap-nanjing.myqcloud.com/%E5%BC%95%E5%AF%BC%E8%B6%85%E9%93%BE%E6%8E%A5%2Fproject.jpg" width="100%"/>
    </a>   
</p>

<p align="center" id='11个软件-banner'>
    <a target="_blank" href='https://mp.weixin.qq.com/s/w9ITodQR3kzSXc4t1H92nw'>
    <img src="https://website-python-1300615378.cos.ap-nanjing.myqcloud.com/%E5%BC%95%E5%AF%BC%E8%B6%85%E9%93%BE%E6%8E%A5%2Fsoft-11.jpg" width="100%"/>
    </a>   
</p>


<p align="center" id='25个学习资源-banner'>
    <a target="_blank" href='https://mp.weixin.qq.com/s/-mlsV7PFc27JElOTCskMsg'>
    <img src="https://website-python-1300615378.cos.ap-nanjing.myqcloud.com/%E5%BC%95%E5%AF%BC%E8%B6%85%E9%93%BE%E6%8E%A5%2Fpy-25-source.jpg" width="100%"/>
    </a>   
</p>

<p align="center" id='支付宝-banner'>
    <a target="_blank" href='https://mp.weixin.qq.com/s/TSnAjBs2dILSI_pM1pPznQ'>
    <img src="https://website-python-1300615378.cos.ap-nanjing.myqcloud.com/ads%2F%E8%81%94%E7%9B%9F%E5%B9%BF%E5%91%8A%2Falipay.jpg" width="100%"/>
    </a>   
</p>


<p align="center" id='外卖-banner'>
    <a target="_blank" href='https://mp.weixin.qq.com/s/fdQ0TbTocPvw-DAMsFUlVg'>
    <img src="https://website-python-1300615378.cos.ap-nanjing.myqcloud.com/ads%2F%E8%81%94%E7%9B%9F%E5%B9%BF%E5%91%8A%2F%E5%A4%96%E5%8D%96-1040-100.jpg" width="100%"/>
    </a>   
</p>
